Package: spatialEco
Type: Package
Title: Spatial Analysis and Modelling Utilities
Version: 2.0-5
Date: 2026-05-19
Authors@R: c(
    person(family="Evans", given="Jeffrey S.", email = "sage_insights@outlook.com", 
         role = c("aut", "cre"), comment = c(ORCID = "0000-0002-5533-7044")),
  person(family="Murphy", given="Melanie A.", role = "ctb"),			 
  person(family="Ram", given="Karthik", role = "ctb") )
Description: Utilities to support spatial data manipulation, query, sampling
    and modelling in ecological applications. Functions include models for species 
	population density, spatial smoothing, multivariate separability, point process 
	model for creating pseudo- absences and sub-sampling, Quadrant-based sampling and 
	analysis, auto-logistic modeling, sampling models, cluster optimization, statistical 
	exploratory tools and raster-based metrics.
Depends: R (>= 4.2)
Imports: sf, terra
Suggests: spatstat.geom (>= 3.0-3), spatstat.explore, spdep, ks,
        cluster, readr, RCurl, RANN, rms, yaImpute, mgcv, zyp,
        SpatialPack (>= 0.3), MASS, caret, dplyr, earth, Matrix, gstat,
        spatstat.data, methods, units, sp, stringr, lwgeom, geodata
Maintainer: Jeffrey S. Evans <sage_insights@outlook.com>
License: GPL-3
URL: https://github.com/jeffreyevans/spatialEco,
        https://jeffreyevans.github.io/spatialEco/
BugReports: https://github.com/jeffreyevans/spatialEco/issues
NeedsCompilation: no
Repository: CRAN
LazyData: true
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
Packaged: 2026-05-19 18:19:06 UTC; sage_
Author: Jeffrey S. Evans [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5533-7044>),
  Melanie A. Murphy [ctb],
  Karthik Ram [ctb]
Date/Publication: 2026-05-20 06:20:03 UTC
Built: R 4.6.0; ; 2026-05-22 00:21:47 UTC; unix
