# Generated by roxygen2: do not edit by hand

S3method(plot,effect.size)
S3method(plot,loess.boot)
S3method(print,cross.cor)
S3method(print,effect.size)
S3method(print,loess.boot)
S3method(print,poly.trend)
S3method(summary,cross.cor)
S3method(summary,effect.size)
S3method(summary,loess.boot)
export(all_pairwise)
export(annulus.matrix)
export(aspline.downscale)
export(background)
export(bbox_poly)
export(bearing.distance)
export(breeding.density)
export(built.index)
export(cgls_urls)
export(chae)
export(classBreaks)
export(collinear)
export(combine)
export(concordance)
export(conf.interval)
export(correlogram)
export(cross.tab)
export(crossCorrelation)
export(csi)
export(curvature)
export(dahi)
export(date_seq)
export(daymet.point)
export(daymet.tiles)
export(dispersion)
export(dissection)
export(divergence)
export(effect.size)
export(erase.point)
export(extract.vertices)
export(fuzzySum)
export(gaussian.kernel)
export(geo.buffer)
export(group.pdf)
export(hexagons)
export(hli)
export(hli.pt)
export(hsp)
export(hybrid.kmeans)
export(idw.smoothing)
export(impute.loess)
export(insert)
export(insert.values)
export(is.empty)
export(kendall)
export(kl.divergence)
export(knn)
export(lai)
export(local.min.max)
export(loess.boot)
export(loess.ci)
export(logistic.regression)
export(max_extent)
export(mean_angle)
export(moments)
export(morans.plot)
export(nni)
export(nth.values)
export(o.ring)
export(oli.aws)
export(optimal.k)
export(optimized.sample.variance)
export(outliers)
export(overlap)
export(parea.sample)
export(parse.bits)
export(partial.cor)
export(poly.regression)
export(polyPerimeter)
export(poly_trend)
export(pp.subsample)
export(proximity.index)
export(pseudo.absence)
export(quadrats)
export(random.raster)
export(raster.Zscore)
export(raster.change)
export(raster.deviation)
export(raster.downscale)
export(raster.entropy)
export(raster.gaussian.smooth)
export(raster.invert)
export(raster.kendall)
export(raster.mds)
export(raster.modified.ttest)
export(raster.moments)
export(raster.transformation)
export(raster.vol)
export(rasterCorrelation)
export(rasterDistance)
export(remove.holes)
export(remove_duplicates)
export(rm.ext)
export(rotate.polygon)
export(sa.trans)
export(sample.annulus)
export(sampleTransect)
export(sar)
export(separability)
export(sf.kde)
export(sf_dissolve)
export(sg.smooth)
export(shannons)
export(shift)
export(sieve)
export(similarity)
export(smooth.time.series)
export(sobal)
export(sp.kde)
export(spatial.select)
export(spatialEcoNews)
export(spectral.separability)
export(spherical.sd)
export(squareBuffer)
export(srr)
export(stratified.random)
export(subsample.distance)
export(swvi)
export(time_to_event)
export(topo.distance)
export(tpi)
export(trasp)
export(trend.line)
export(tri)
export(vrm)
export(winsorize)
export(wt.centroid)
export(z_normalization)
import(terra)
