#' @name TM5
#' @docType data
#'
#' @title Landsat 5 TM Scene
#'
#' @description 
#' Subset of Landsat 5 TM Scene: LT52240631988227CUB02 Contains six bands of surface reflectance
#' path 224/row 63 acquisition date: 1988-08-14 13:00:47 GMT, EPSG:32622
#'
#' @format A tif (inst/extdata/Landsat_TM5.tif) with 30m 6 bands:
#' \describe{
#'   \item{Blue}{0.45 - 0.52 µm}
#'   \item{Green}{0.52 - 0.60 µm}
#'   \item{Red}{0.63 - 0.69 µm}
#'   \item{NIR Near-Infrared}{0.76 - 0.90 µm}
#'   \item{SWIR1 Near-Infrared}{1.55 - 1.75 µm}
#'   \item{SWIR2 Mid-Infrared}{2.08 - 2.35 µm}
#' }
#'
NULL
