#' @name cor.data 
#' @description linear and nonlinear correlated data examples
#' @docType data
#'
#' @title Various correlation structures
#'
#' @description 
#' A list object with various linear and nonlinear correlation structures
#'
#' @format A list object with 4 elements containing data.frames:
#' \describe{
#'   \item{example 1}{two columns with nonlinear wave function relationship}
#'   \item{example 2}{two columns with simple nonlinear relationship}
#'   \item{example 3}{two columns with nonlinear multi-level wave function relationship}
#'   \item{example 4}{4 columns with first two having linear relationship}
#' }
#'
NULL