% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.effect.size.R
\name{plot.effect.size}
\alias{plot.effect.size}
\title{Plot effect size}
\usage{
\method{plot}{effect.size}(x, ...)
}
\arguments{
\item{x}{A effect.size object}

\item{...}{Additional arguments passed to plot}
}
\value{
Plot of effect size object with group effect sizes and 95% confidence
}
\description{
Plot function for effect.size object
}
\author{
Jeffrey S. Evans  <sage_insights@outlook.com>
}
